@@ -171,7 +171,7 @@ def read_md_problem(filepath):
 
     for k,v in blocks.items():
 
-        rendered_part = MDRenderer().render(tokens[v[0]:v[1]], mdit.options, env)
+        rendered_part = codecs.unicode_escape_decode(MDRenderer().render(tokens[v[0]:v[1]], mdit.options, env))[0]
 
         if k == 'title':
             body_parts['title'] = rendered_part
@@ -249,6 +249,8 @@ def write_server_py(output_path,parsed_question):
         parsed_question ([type]): [description]
     """
     
+    output_path = pathlib.Path(output_path)
+    
     server_dict = parsed_question['header']['server']
     
     server_file = f""""""
@@ -264,7 +266,8 @@ def write_server_py(output_path,parsed_question):
         raise
 
     # Deal with path differences when using PL
-    server_file = server_file.replace('read_csv("','read_csv(data["options"]["client_files_course_path"]+"/')
+    server_file = server_file.replace('read_csv("',
+                                      'read_csv(data["options"]["client_files_course_path"]+"/')
 
     # Write server.py
     (output_path / "server.py").write_text(server_file,encoding='utf8')
@@ -415,16 +418,16 @@ def process_attribution(source):
     """
     try:
         if 'openstax-physics-vol1' in source:
-            attribution_text = "![Image representing the Creative Commons 4.0 BY license.](https://raw.githubusercontent.com/firasm/bits/master/by.png) Problem is from the [OpenStax University Physics Volume 1](https://openstax.org/details/books/university-physics-volume-1) textbook, licensed under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/)."
+            attribution_text = "Problem is from the [OpenStax University Physics Volume 1](https://openstax.org/details/books/university-physics-volume-1) textbook, licensed under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/).\n![Image representing the Creative Commons 4.0 BY license.](https://raw.githubusercontent.com/firasm/bits/master/by.png)"
 
         elif 'openstax-physics-vol2' in source:
-            attribution_text = "![Image representing the Creative Commons 4.0 BY license.](https://raw.githubusercontent.com/firasm/bits/master/by.png) Problem is from the [OpenStax University Physics Volume 2](https://openstax.org/details/books/university-physics-volume-2) textbook, licensed under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/)."
+            attribution_text = "Problem is from the [OpenStax University Physics Volume 2](https://openstax.org/details/books/university-physics-volume-2) textbook, licensed under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/).\n![Image representing the Creative Commons 4.0 BY license.](https://raw.githubusercontent.com/firasm/bits/master/by.png)"
 
         elif 'ubc-mech2' in source:
             raise NotImplementedError
 
         elif 'standard' in source:
-            attribution_text = "![The Creative Commons 4.0 license requiring attribution-BY, non-commercial-NC, and share-alike-SA license.](https://raw.githubusercontent.com/firasm/bits/master/by-nc-sa.png) Problem is licensed under the [CC-BY-NC-SA 4.0 license](https://creativecommons.org/licenses/by-nc-sa/4.0/)."
+            attribution_text = "Problem is licensed under the [CC-BY-NC-SA 4.0 license](https://creativecommons.org/licenses/by-nc-sa/4.0/).\n![The Creative Commons 4.0 license requiring attribution-BY, non-commercial-NC, and share-alike-SA license.](https://raw.githubusercontent.com/firasm/bits/master/by-nc-sa.png)"
     
         return attribution_text
     
@@ -450,7 +453,7 @@ def process_question_md(source_filepath, output_path = None, instructor = False)
         ## TODO: Make this a bit more robust
         output_path = pathlib.Path(output_path)
         print(f"Warning: This feature (specifying your own directory {output_path}) is not tested!")
-    
+
     # deal with multi-line strings in YAML Dump
     ## Code copied from here: https://stackoverflow.com/a/33300001/2217577
 
@@ -548,10 +551,11 @@ def process_question_pl(source_filepath, output_path = None):
 
     # Question Preamble
     if parsed_q['body_parts']['preamble']:
-        question_html = f"<markdown>\n{ codecs.unicode_escape_decode(parsed_q['body_parts']['preamble'])[0] }\n</markdown>\n\n"
+        question_html = f"<pl-question-panel>\n<markdown>\n{ parsed_q['body_parts']['preamble'] }\n</markdown>\n</pl-question-panel>\n\n"
     else:
         question_html = f""
 
+
     ## Single part questions
     if parsed_q['num_parts'] == 1:
         q_type = parsed_q['header']['part1']['type']
@@ -593,22 +597,27 @@ def process_question_pl(source_filepath, output_path = None):
 
             question_html += "</div>\n</div>\n\n\n"
 
-    # Add pl-submission-panel and pl-answer-panel
+    # Add pl-submission-panel and pl-answer-panel (if they exist)
+    subm_panel = parsed_q['body_parts_split'].get('pl-submission-panel', None)
+    q_panel = parsed_q['body_parts_split'].get('pl-answer-panel', None)
 
-    if parsed_q['body_parts_split']['pl-submission-panel']:
+    if subm_panel:
         question_html += f"<pl-submission-panel>{ parsed_q['body_parts_split']['pl-submission-panel'] } </pl-submission-panel>\n"
 
-    if parsed_q['body_parts_split']['pl-answer-panel']:
+    if q_panel:
         question_html += f"<pl-answer-panel>{ parsed_q['body_parts_split']['pl-answer-panel'] } </pl-answer-panel>\n"
 
     # Add Attribution
-    question_html += f"\n<markdown>---\n{process_attribution(parsed_q['header'].get('attribution'))}\n</markdown>"
+    question_html += f"\n<pl-question-panel>\n<markdown>\n---\n{process_attribution(parsed_q['header'].get('attribution'))}\n</markdown>\n</pl-question-panel>\n"
+
+    # Fix Latex underscore bug (_ being replaced with \_)
+    question_html = question_html.replace('\\_','_')
 
     # Final pre-processing
     question_html = pl_image_path(question_html)
 
     # Write question.html file
-    (output_path / "question.html").write_text(question_html,encoding='utf8') #,encoding='raw_unicode_escape')
+    (output_path / "question.html").write_text(question_html,encoding='utf8')
 
     ### TODO solve the issue with the latex escape sequences, this is a workaround
     # with open((output_path / "question.html"), "w") as qfile:
